#
# spec file for package python-astral
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-astral
Version:        3.2
Release:        1.8
Summary:        Calculations for the position of the sun and moon
License:        Apache-2.0
URL:            https://github.com/sffjunkie/astral
Source:         https://files.pythonhosted.org/packages/source/a/astral/astral-%{version}.tar.gz
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  (python36-dataclasses if python36-base)
Requires:       python-pytz
Requires:       python-requests
Recommends:     python-dataclasses
BuildArch:      noarch
%python_subpackages

%description
This is 'astral' a Python module which calculates

* Times for various positions of the sun: dawn, sunrise, solar noon,
  sunset, dusk, solar elevation, solar azimuth and rahukaalam.
* The phase of the moon.

For documentation see the http://astral.readthedocs.io/en/latest/index.html

%prep
%setup -q -n astral-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}/%{$python_sitelib}

%check
%pytest -m "not webtest"

%files %{python_files}
%doc ReadMe.md
%license LICENSE
%{python_sitelib}/astral
%{python_sitelib}/astral-%{version}-py3*.egg-info

%changelog
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0:
  * Adds moon rise, set, azimuth and zenith calculations
* Wed Jan 20 2021 Steve Kowalik <steven.kowalik@suse.com>
- BuildRequire dataclasses if python36-base installed
* Tue Nov  3 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix %%check on Leap 15.2
* Fri Jun 12 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 2.2:
  * Fix for bug #48. As per the bug report the angle to adjust for
    the effect of elevation should have been θ (not α).
  * The sun functions can now also be passed the timezone as a
    string. Previously only a pytz timezone was accepted.
* Fri Mar  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not install doc and test folders to sitelib
* Thu Mar  5 2020 pgajdos@suse.com
- version update to 2.1
  * v2.0 - Python 3 only
  * Fix for documentation on PyPi
  * Added python to code-block directives
  * Fix for bug #44
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.10.1:
  * Keywords arguments to Astral init are now passed to the geocoder
  * Added method to AstralGeocoder to add locations to the database
  * Version 1.9 broke the sun_utc method. Sun UTC calculation passed incorrect parameter
  * Corrected version number in module source code
  * Sun calculations now take into account the elevation of the location
  * Added command line interface to return sun information as json
- Run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Nov 12 2018 Matěj Cepl <mcepl@suse.com>
- Make package buildable on Leap 42.* (SLE 12.*) as well.
* Mon Nov 12 2018 Adrian Schröter <adrian@suse.de>
- update to version 1.7.1
  * Requests is now only needed when using GoogleGeocoder
  * GoogleGeocoder now requires the `api_key` parameter to be passed to the constructor
* Mon May 14 2018 adrian@suse.de
- update to version 1.6.1
  * minor fixes
* Sun Mar  4 2018 alarrosa@suse.com
- Update to python-astral 1.6:
  * Added api_key parameter to GoogleGeocoder init method.
- Add LICENSE file from upstream's git.
* Mon Feb 12 2018 adrian@suse.de
- update to version 1.5
  * dawn_utc, sunrise_utc, sunset_utc and dusk_utc now only raise AstralError
    for a math domain exception all other exceptions are passed through.
  * moon_phase now takes another parameter if the type to return either
    int (the default) or float
* Mon Sep 11 2017 aloisio@gmx.com
- Update to version 1.4
- Converted to single-spec
* Wed Feb 22 2017 toms@opensuse.org
- First public release 1.3.4 on OBS
